Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/asmjit/asmjit.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorkobalicek <kobalicek.petr@gmail.com>2021-06-27 01:39:18 +0300
committerkobalicek <kobalicek.petr@gmail.com>2021-06-27 01:39:18 +0300
commit0a709c7a28ba83c6d4e68e528bd39fd0ce734262 (patch)
treeee7e4e5ebdc58490591d55033e7705c7ab1e5340 /tools
parentc329fa7ce0f210ab650ed4c930d3da7e1f8ae33f (diff)
In addition to LEA, allow CL* and PREFETCH* instructions to have memory operand of any size
Diffstat (limited to 'tools')
-rw-r--r--tools/tablegen-x86.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/tablegen-x86.js b/tools/tablegen-x86.js
index 8fa6e25..2ddaa3a 100644
--- a/tools/tablegen-x86.js
+++ b/tools/tablegen-x86.js
@@ -1675,8 +1675,8 @@ class InstSignatureTable extends core.Task {
}
if (mem) {
op.flags[mem] = true;
- // HACK: Allow LEA to use any memory size.
- if (inst.name === "lea") {
+ // HACK: Allow LEA|CL*|PREFETCH* to use any memory size.
+ if (/^(cldemote|clwb|clflush\w*|lea|prefetch\w*)$/.test(inst.name)) {
op.flags.mem = true;
Object.assign(op.flags, MemOp);
}